@@ -25,8 +25,6 @@
 
 #include <glib-object.h>
 
-G_BEGIN_DECLS
-
 typedef struct _ChamplainPoint ChamplainPoint;
 
 struct _ChamplainPoint
@@ -46,6 +44,4 @@ void champlain_point_free (ChamplainPoint *point);
 ChamplainPoint * champlain_point_new (gdouble lat,
     gdouble lon);
 
-G_END_DECLS
-
 #endif
