@@ -49,14 +49,17 @@ G_BEGIN_DECLS
 
 typedef struct _ChamplainPolygonPrivate ChamplainPolygonPrivate;
 
-typedef struct {
+typedef struct _ChamplainPolygon        ChamplainPolygon;
+typedef struct _ChamplainPolygonClass   ChamplainPolygonClass;
+
+struct _ChamplainPolygon {
   GInitiallyUnowned parent;
   ChamplainPolygonPrivate *priv;
-} ChamplainPolygon;
+};
 
-typedef struct {
+struct _ChamplainPolygonClass {
   GInitiallyUnownedClass parent_class;
-} ChamplainPolygonClass;
+};
 
 GType champlain_polygon_get_type (void);
 
@@ -90,6 +93,9 @@ void champlain_polygon_set_stroke (ChamplainPolygon *polygon,
 void champlain_polygon_set_stroke_width (ChamplainPolygon *polygon,
     gdouble value);
 gdouble champlain_polygon_get_stroke_width (ChamplainPolygon *polygon);
+void champlain_polygon_set_mark_points (ChamplainPolygon *polygon,
+    gboolean value);
+gboolean champlain_polygon_get_mark_points (ChamplainPolygon *polygon);
 
 void champlain_polygon_show (ChamplainPolygon *polygon);
 void champlain_polygon_hide (ChamplainPolygon *polygon);
