@@ -47,8 +47,6 @@ enum
   PROP_Y,
   PROP_ZOOM_LEVEL,
   PROP_SIZE,
-  PROP_URI,
-  PROP_FILENAME,
   PROP_STATE,
   PROP_ACTOR,
   PROP_CONTENT,
@@ -56,21 +54,17 @@ enum
 };
 
 struct _ChamplainTilePrivate {
-  gint x;
-  gint y;
-  gint size;
-  gint zoom_level;
+  gint x; /* The x position on the map (in pixels) */
+  gint y; /* The y position on the map (in pixels) */
+  gint size; /* The tile's width and height (only support square tiles */
+  gint zoom_level; /* The tile's zoom level */
 
-  gchar * uri;
-  gpointer data;
-  ChamplainState state;
-  gchar *filename;
-  ClutterActor *actor;
-  ClutterActor *content_actor;
-  ClutterAnimation *animation;
+  ChamplainState state; /* The tile state: loading, validation, done */
+  ClutterActor *actor; /* An actor grouping all content actors */
+  ClutterActor *content_actor; /* The actual tile actor */
 
-  GTimeVal *modified_time;
-  gchar* etag;
+  GTimeVal *modified_time; /* The last modified time of the cache */
+  gchar* etag; /* The HTTP ETag sent by the server */
 };
 
 static void
@@ -97,12 +91,6 @@ champlain_tile_get_property (GObject *object,
       case PROP_STATE:
         g_value_set_enum (value, champlain_tile_get_state (self));
         break;
-      case PROP_URI:
-        g_value_set_string (value, champlain_tile_get_uri (self));
-        break;
-      case PROP_FILENAME:
-        g_value_set_string (value, champlain_tile_get_filename (self));
-        break;
       case PROP_ACTOR:
         g_value_set_object (value, champlain_tile_get_actor (self));
         break;
@@ -141,12 +129,6 @@ champlain_tile_set_property (GObject *object,
       case PROP_STATE:
         champlain_tile_set_state (self, g_value_get_enum (value));
         break;
-      case PROP_URI:
-        champlain_tile_set_uri (self, g_value_get_string (value));
-        break;
-      case PROP_FILENAME:
-        champlain_tile_set_filename (self, g_value_get_string (value));
-        break;
       case PROP_CONTENT:
         champlain_tile_set_content (self, g_value_get_object (value), FALSE);
         break;
@@ -163,14 +145,6 @@ champlain_tile_dispose (GObject *object)
 {
   ChamplainTilePrivate *priv = CHAMPLAIN_TILE (object)->priv;
 
-  /* Force the animation to finish */
-  if (priv->animation != NULL)
-    {
-      clutter_animation_completed (priv->animation);
-      /* this will call the animation complete callback and free the context,
-       * the animation object will be unreffed too */
-    }
-
   if (priv->actor != NULL)
     {
       g_object_unref (G_OBJECT (priv->actor));
@@ -186,13 +160,13 @@ champlain_tile_dispose (GObject *object)
   G_OBJECT_CLASS (champlain_tile_parent_class)->dispose (object);
 }
 
+
+
 static void
 champlain_tile_finalize (GObject *object)
 {
   ChamplainTilePrivate *priv = CHAMPLAIN_TILE (object)->priv;
 
-  g_free (priv->uri);
-  g_free (priv->filename);
   g_free (priv->modified_time);
   g_free (priv->etag);
 
@@ -211,7 +185,6 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   object_class->dispose = champlain_tile_dispose;
   object_class->finalize = champlain_tile_finalize;
 
-
   /**
   * ChamplainTile:x:
   *
@@ -222,12 +195,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_X,
       g_param_spec_int ("x",
-        "x",
-        "The X position of the tile",
-        G_MININT,
-        G_MAXINT,
-        0,
-        G_PARAM_READWRITE));
+          "x",
+          "The X position of the tile",
+          G_MININT,
+          G_MAXINT,
+          0,
+          G_PARAM_READWRITE));
 
   /**
   * ChamplainTile:y:
@@ -239,12 +212,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_Y,
       g_param_spec_int ("y",
-        "y",
-        "The Y position of the tile",
-        G_MININT,
-        G_MAXINT,
-        0,
-        G_PARAM_READWRITE));
+          "y",
+          "The Y position of the tile",
+          G_MININT,
+          G_MAXINT,
+          0,
+          G_PARAM_READWRITE));
 
   /**
   * ChamplainTile:zoom-level:
@@ -256,12 +229,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_ZOOM_LEVEL,
       g_param_spec_int ("zoom-level",
-        "Zoom Level",
-        "The zoom level of the tile",
-        G_MININT,
-        G_MAXINT,
-        0,
-        G_PARAM_READWRITE));
+          "Zoom Level",
+          "The zoom level of the tile",
+          G_MININT,
+          G_MAXINT,
+          0,
+          G_PARAM_READWRITE));
 
   /**
   * ChamplainTile:size:
@@ -273,12 +246,12 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_SIZE,
       g_param_spec_uint ("size",
-        "Size",
-        "The size of the tile",
-        0,
-        G_MAXINT,
-        256,
-        G_PARAM_READWRITE));
+          "Size",
+          "The size of the tile",
+          0,
+          G_MAXINT,
+          256,
+          G_PARAM_READWRITE));
 
   /**
   * ChamplainTile:state:
@@ -290,41 +263,11 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_STATE,
       g_param_spec_enum ("state",
-        "State",
-        "The state of the tile",
-        CHAMPLAIN_TYPE_STATE,
-        CHAMPLAIN_STATE_NONE,
-        G_PARAM_READWRITE));
-
-  /**
-  * ChamplainTile:uri:
-  *
-  * The remote uri of the tile
-  *
-  * Since: 0.4
-  */
-  g_object_class_install_property (object_class,
-      PROP_URI,
-      g_param_spec_string ("uri",
-        "URI",
-        "The URI of the tile",
-        "",
-        G_PARAM_READWRITE));
-
-  /**
-  * ChamplainTile:filename:
-  *
-  * The local path of the cached tile
-  *
-  * Since: 0.4
-  */
-  g_object_class_install_property (object_class,
-      PROP_FILENAME,
-      g_param_spec_string ("filename",
-        "Filename",
-        "The filename of the tile",
-        "",
-        G_PARAM_READWRITE));
+          "State",
+          "The state of the tile",
+          CHAMPLAIN_TYPE_STATE,
+          CHAMPLAIN_STATE_NONE,
+          G_PARAM_READWRITE));
 
   /**
   * ChamplainTile:actor:
@@ -337,10 +280,10 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_ACTOR,
       g_param_spec_object ("actor",
-        "Actor",
-        "The tile's actor",
-        CLUTTER_TYPE_ACTOR,
-        G_PARAM_READABLE));
+          "Actor",
+          "The tile's actor",
+          CLUTTER_TYPE_ACTOR,
+          G_PARAM_READABLE));
 
   /**
   * ChamplainTile:content:
@@ -353,10 +296,10 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_CONTENT,
       g_param_spec_object ("content",
-        "Content",
-        "The tile's content",
-        CLUTTER_TYPE_ACTOR,
-        G_PARAM_READWRITE));
+          "Content",
+          "The tile's content",
+          CLUTTER_TYPE_ACTOR,
+          G_PARAM_READWRITE));
 
   /**
   * ChamplainTile:etag:
@@ -370,10 +313,10 @@ champlain_tile_class_init (ChamplainTileClass *klass)
   g_object_class_install_property (object_class,
       PROP_ETAG,
       g_param_spec_string ("etag",
-        "Entity Tag",
-        "The entity tag of the tile",
-        NULL,
-        G_PARAM_READWRITE));
+          "Entity Tag",
+          "The entity tag of the tile",
+          NULL,
+          G_PARAM_READWRITE));
 
 }
 
@@ -388,8 +331,6 @@ champlain_tile_init (ChamplainTile *self)
   priv->y = 0;
   priv->zoom_level = 0;
   priv->size = 0;
-  priv->uri = g_strdup ("");
-  priv->filename = g_strdup ("");
   priv->modified_time = NULL;
   priv->etag = NULL;
 
@@ -397,13 +338,12 @@ champlain_tile_init (ChamplainTile *self)
   g_object_add_weak_pointer (G_OBJECT (priv->actor), (gpointer*)&priv->actor);
 
   priv->content_actor = NULL;
-  priv->animation = NULL;
 }
 
 /**
  * champlain_tile_new:
  *
- * Returns a new #ChamplainTile
+ * Returns: a new #ChamplainTile
  *
  * Since: 0.4
  */
@@ -417,141 +357,95 @@ champlain_tile_new (void)
  * champlain_tile_get_x:
  * @self: the #ChamplainTile
  *
- * Returns the tile's x position
+ * Returns: the tile's x position
  *
  * Since: 0.4
  */
 gint
 champlain_tile_get_x (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), 0);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), 0);
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->x;
+  return self->priv->x;
 }
 
 /**
  * champlain_tile_get_y:
  * @self: the #ChamplainTile
  *
- * Returns the tile's y position
+ * Returns: the tile's y position
  *
  * Since: 0.4
  */
 gint
 champlain_tile_get_y (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), 0);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), 0);
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->y;
+  return self->priv->y;
 }
 
 /**
  * champlain_tile_get_zoom_level:
  * @self: the #ChamplainTile
  *
- * Returns the tile's zoom level
+ * Returns: the tile's zoom level
  *
  * Since: 0.4
  */
 gint
 champlain_tile_get_zoom_level (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), 0);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), 0);
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->zoom_level;
+  return self->priv->zoom_level;
 }
 
 /**
  * champlain_tile_get_size:
  * @self: the #ChamplainTile
  *
- * Returns the tile's size in pixels
+ * Returns: the tile's size in pixels
  *
  * Since: 0.4
  */
 guint
 champlain_tile_get_size (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), 0);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), 0);
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->size;
+  return self->priv->size;
 }
 
 /**
  * champlain_tile_get_state:
  * @self: the #ChamplainTile
  *
- * Returns the tile's #ChamplainState
+ * Returns: the tile's #ChamplainState
  *
  * Since: 0.4
  */
 ChamplainState
 champlain_tile_get_state (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), CHAMPLAIN_STATE_NONE);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), CHAMPLAIN_STATE_NONE);
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->state;
-}
-
-/**
- * champlain_tile_get_uri:
- * @self: the #ChamplainTile
- *
- * Returns the tile's remote uri
- *
- * Since: 0.4
- */
-G_CONST_RETURN gchar *
-champlain_tile_get_uri (ChamplainTile *self)
-{
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), NULL);
-
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->uri;
-}
-
-/**
- * champlain_tile_get_filename:
- * @self: the #ChamplainTile
- *
- * Returns the tile's local filename
- *
- * Since: 0.4
- */
-G_CONST_RETURN gchar *
-champlain_tile_get_filename (ChamplainTile *self)
-{
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), NULL);
-
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->filename;
+  return self->priv->state;
 }
 
 /**
  * champlain_tile_get_actor:
  * @self: the #ChamplainTile
  *
- * Returns the tile's actor.  This actor should not change during the tile's
- * lifetime.
+ * Returns: the tile's actor.  This actor should not change during the tile's
+ * lifetime. You should not unref this actor, it is owned by the tile.
  *
  * Since: 0.4
  */
 ClutterActor *
 champlain_tile_get_actor (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), NULL);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), NULL);
 
   return self->priv->actor;
 }
@@ -569,15 +463,9 @@ void
 champlain_tile_set_x (ChamplainTile *self,
     gint x)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  priv->x = x;
-
-  if (priv->actor != NULL)
-    clutter_actor_set_position (priv->actor, priv->x * priv->size,
-        priv->y * priv->size);
+  self->priv->x = x;
 
   g_object_notify (G_OBJECT (self), "x");
 }
@@ -595,14 +483,10 @@ void
 champlain_tile_set_y (ChamplainTile *self,
     gint y)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
 
-  ChamplainTilePrivate *priv = self->priv;
+  self->priv->y = y;
 
-  priv->y = y;
-  if (priv->actor != NULL)
-    clutter_actor_set_position (priv->actor, priv->x * priv->size,
-        priv->y * priv->size);
   g_object_notify (G_OBJECT (self), "y");
 }
 
@@ -619,11 +503,10 @@ void
 champlain_tile_set_zoom_level (ChamplainTile *self,
     gint zoom_level)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
 
-  ChamplainTilePrivate *priv = self->priv;
+  self->priv->zoom_level = zoom_level;
 
-  priv->zoom_level = zoom_level;
   g_object_notify (G_OBJECT (self), "zoom-level");
 }
 
@@ -632,7 +515,7 @@ champlain_tile_set_zoom_level (ChamplainTile *self,
  * @self: the #ChamplainTile
  * @size: the size in pixels
  *
- * Sets the tile's zoom level
+ * Sets the tile's size
  *
  * Since: 0.4
  */
@@ -640,15 +523,10 @@ void
 champlain_tile_set_size (ChamplainTile *self,
     guint size)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
 
-  ChamplainTilePrivate *priv = self->priv;
+  self->priv->size = size;
 
-  priv->size = size;
-
-  if (priv->actor != NULL)
-    clutter_actor_set_position (priv->actor, priv->x * priv->size,
-        priv->y * priv->size);
   g_object_notify (G_OBJECT (self), "size");
 }
 
@@ -665,23 +543,21 @@ void
 champlain_tile_set_state (ChamplainTile *self,
     ChamplainState state)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
 
-  ChamplainTilePrivate *priv = self->priv;
+  self->priv->state = state;
 
-  priv->state = state;
   g_object_notify (G_OBJECT (self), "state");
 }
 
 /**
  * champlain_tile_new_full:
- * @self: the #ChamplainTile
  * @x: the x position
  * @y: the y position
  * @size: the size in pixels
  * @zoom_level: the zoom level
  *
- * Returns a #ChamplainTile
+ * Returns: a #ChamplainTile
  *
  * Since: 0.4
  */
@@ -695,74 +571,26 @@ champlain_tile_new_full (gint x,
       zoom_level, "size", size, NULL);
 }
 
-/**
- * champlain_tile_set_uri:
- * @self: the #ChamplainTile
- * @uri: the uri
- *
- * Sets the tile's uri
- *
- * Since: 0.4
- */
-void
-champlain_tile_set_uri (ChamplainTile *self,
-    const gchar *uri)
-{
-  g_return_if_fail(CHAMPLAIN_TILE(self));
-  g_return_if_fail(uri != NULL);
-
-  ChamplainTilePrivate *priv = self->priv;
-
-  g_free (priv->uri);
-  priv->uri = g_strdup (uri);
-  g_object_notify (G_OBJECT (self), "uri");
-}
-
-/**
- * champlain_tile_set_filename:
- * @self: the #ChamplainTile
- * @filename: a local path to an image
- *
- * Sets the tile's filename
- *
- * Since: 0.4
- */
-void
-champlain_tile_set_filename (ChamplainTile *self,
-    const gchar *filename)
-{
-  g_return_if_fail(CHAMPLAIN_TILE(self));
-  g_return_if_fail(filename != NULL);
-
-  ChamplainTilePrivate *priv = self->priv;
-
-  g_free (priv->filename);
-  priv->filename = g_strdup (filename);
-  g_object_notify (G_OBJECT (self), "filename");
-}
-
 /**
  * champlain_tile_get_modified_time:
  * @self: the #ChamplainTile
  *
- * Returns the tile's last modified time
+ * Returns: the tile's last modified time
  *
  * Since: 0.4
  */
-const GTimeVal *
+G_CONST_RETURN GTimeVal *
 champlain_tile_get_modified_time (ChamplainTile *self)
 {
-  g_return_val_if_fail (CHAMPLAIN_TILE(self), NULL);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), NULL);
 
-  ChamplainTilePrivate *priv = self->priv;
-
-  return priv->modified_time;
+  return self->priv->modified_time;
 }
 
 /**
  * champlain_tile_set_modified_time:
  * @self: the #ChamplainTile
- * @time_: a #GTimeVal, the value will be copied
+ * @time: a #GTimeVal, the value will be copied
  *
  * Sets the tile's modified time
  *
@@ -772,7 +600,7 @@ void
 champlain_tile_set_modified_time (ChamplainTile *self,
     const GTimeVal *time_)
 {
-  g_return_if_fail (CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
   g_return_if_fail (time != NULL);
 
   ChamplainTilePrivate *priv = self->priv;
@@ -785,14 +613,15 @@ champlain_tile_set_modified_time (ChamplainTile *self,
  * champlain_tile_get_modified_time_string:
  * @self: the #ChamplainTile
  *
- * Returns the tile's modified time as a string
+ * Returns: the tile's modified time as a string (formated as per RFC 1123)
  *
  * Since: 0.4
  */
 gchar *
 champlain_tile_get_modified_time_string (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), NULL);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), NULL);
+
   ChamplainTilePrivate *priv = self->priv;
 
   if (priv->modified_time == NULL)
@@ -810,14 +639,14 @@ champlain_tile_get_modified_time_string (ChamplainTile *self)
  * champlain_tile_get_etag:
  * @self: the #ChamplainTile
  *
- * Returns the tile's ETag
+ * Returns: the tile's ETag
  *
  * Since: 0.4
  */
-const gchar *
+G_CONST_RETURN gchar *
 champlain_tile_get_etag (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), "");
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), "");
 
   return self->priv->etag;
 }
@@ -835,7 +664,7 @@ void
 champlain_tile_set_etag (ChamplainTile *self,
     const gchar *etag)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
+  g_return_if_fail (CHAMPLAIN_TILE (self));
 
   ChamplainTilePrivate *priv = self->priv;
 
@@ -851,32 +680,28 @@ typedef struct {
 
 static void
 fade_in_completed (ClutterAnimation *animation,
-    gpointer data)
+    ClutterActor *old_actor)
 {
-  AnimationContext* ctx = (AnimationContext*) data;
-  ChamplainTilePrivate *priv = ctx->tile->priv;
+  ClutterActor *parent;
 
-  priv->animation = NULL;
+  if (old_actor == NULL)
+    return;
 
-  if (ctx->old_actor != NULL)
-    {
-      if (priv->actor != NULL)
-        clutter_container_remove (CLUTTER_CONTAINER (priv->actor), ctx->old_actor, NULL);
-      g_object_unref (ctx->old_actor);
-    }
+  parent = clutter_actor_get_parent (old_actor);
 
-  g_object_unref (ctx->tile);
-  g_free (ctx);
+  if (parent != NULL)
+    clutter_container_remove (CLUTTER_CONTAINER (parent), old_actor, NULL);
+
+  g_object_unref (old_actor);
 }
 
-
 /**
  * champlain_tile_set_content:
  * @self: the #ChamplainTile
  * @actor: the new content
  * @fade_in: if the new content should be faded in
  *
- * Returns the tile's content
+ * Sets the tile's content
  *
  * Since: 0.4
  */
@@ -885,16 +710,12 @@ champlain_tile_set_content (ChamplainTile *self,
     ClutterActor *actor,
     gboolean fade_in)
 {
-  g_return_if_fail(CHAMPLAIN_TILE(self));
-  g_return_if_fail(actor != NULL);
+  g_return_if_fail (CHAMPLAIN_TILE (self));
+  g_return_if_fail (actor != NULL);
 
   ChamplainTilePrivate *priv = self->priv;
   ClutterActor *old_actor = NULL;
 
-  /* Don't start another animation if there's already one going on */
-  if (priv->animation != NULL)
-    clutter_animation_completed (priv->animation);
-
   if (priv->content_actor != NULL)
     {
       /* it sometimes happen that the priv->content_actor has been destroyed,
@@ -903,42 +724,47 @@ champlain_tile_set_content (ChamplainTile *self,
 
       if (fade_in == TRUE)
         old_actor = g_object_ref (priv->content_actor);
-      else
+      else if (priv->actor != NULL)
         clutter_container_remove (CLUTTER_CONTAINER (priv->actor), priv->content_actor, NULL);
+
       g_object_unref (priv->content_actor);
     }
 
   if (priv->actor != NULL)
     clutter_container_add (CLUTTER_CONTAINER (priv->actor), actor, NULL);
 
-  if (fade_in == TRUE && priv->actor !=  NULL)
+  if (fade_in == TRUE && priv->actor != NULL)
     {
+      ClutterAnimation *animation;
+
       clutter_actor_set_opacity (actor, 0);
 
-      AnimationContext *ctx = g_new0 (AnimationContext, 1);
-      ctx->tile = g_object_ref (self);
-      priv->animation = clutter_actor_animate (actor, CLUTTER_EASE_IN_CUBIC,
-          500, "opacity", 255, NULL);
-      ctx->old_actor = old_actor;
+      animation = clutter_actor_animate (actor,
+          CLUTTER_EASE_IN_CUBIC,
+          500,
+          "opacity", 255,
+          NULL);
 
-      g_signal_connect (priv->animation, "completed", G_CALLBACK (fade_in_completed), ctx);
+      g_signal_connect (animation, "completed", G_CALLBACK (fade_in_completed), old_actor);
     }
 
   priv->content_actor = g_object_ref (actor);
+
   g_object_notify (G_OBJECT (self), "content");
 }
 
 /**
  * champlain_tile_get_content:
  *
- * Returns the tile's content
+ * Returns: the tile's content, this actor will change each time the tile's content changes.
+ * You should not unref this content, it is owned by the tile.
  *
  * Since: 0.4
  */
 ClutterActor *
 champlain_tile_get_content (ChamplainTile *self)
 {
-  g_return_val_if_fail(CHAMPLAIN_TILE(self), NULL);
+  g_return_val_if_fail (CHAMPLAIN_TILE (self), NULL);
 
   return self->priv->content_actor;
 }
